import Popup from "@/components/popup";
import { Input, ScrollView, Text, View } from "@tarojs/components";
import { memo, useCallback, useMemo, useRef } from "react";
import classnames from "classnames";
import styles  from './index.module.scss'
import TextareaEnhance from "@/components/textareaEnhance";
import { CreateFavoriteApi } from "@/api/favorite";
import { alert } from "@/common/common";

//原因选择
type ReasonInfoParam = {
    show?: boolean, //显示 
    onClose?: () => void, //关闭
    onSuccess?: () => void, //成功
}
export default memo(({show = false, onClose, onSuccess}: ReasonInfoParam) => {
    
    const submitData = useRef({
        "name": '',
        "remark": ''
    })

    const getOtherReason = useCallback((val) => {
        submitData.current.remark = val
    }, [])

    const changeInput = useCallback((val) => {
        submitData.current.name = val.detail.value
    }, [])

    //创建
    const {fetchData} = CreateFavoriteApi()
    const onSubmit = async () => {
        if(!submitData.current.name) return alert.none('请输入收藏夹名称!')
        let res = await fetchData(submitData.current)
        if(res.success) {
            alert.success('创建成功')
            onSuccess?.()
        } else {
            alert.error('创建失败')
        }
        onClose?.()
    }
    return (
        <Popup show={show} onClose={onClose} >
            <View className={styles.collection_con}>
                <View className={styles.collection_item}>
                    <Text className={classnames(styles.miconfont, 'iconfont icon-bianji')}></Text>
                    <Text>编辑收藏夹</Text>
                </View>
                <View className={styles.collection_item}>
                    <Text className={classnames(styles.miconfont, 'iconfont icon-fenlei')}></Text>
                    <Text>批量管理</Text>
                </View>
                <View className={styles.collection_item}>
                    <Text className={classnames(styles.miconfont, 'iconfont icon-shanchu')}></Text>
                    <Text>删除该收藏夹</Text>
                </View>
            </View>
        </Popup>
    )
})